==> jakarta-persistence-tck-3.0.0.zip: persistence-tck/src/com/sun/ts/tests/jpa/core/relationship/bidirmanyxone/BiDirMX1Person.java <==
/*
 * Copyright (c) 2009, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package com.sun.ts.tests.jpa.core.relationship.bidirmanyxone;

import jakarta.persistence.*;
import java.io.Serializable;

/**
 *
 * @author Raja Perumal
 */
@Entity
public class BiDirMX1Person implements Serializable {

  public BiDirMX1Person() {
  }

  private static final long serialVersionUID = 1L;

  @Id
  private Long id;

  private String name;

  // Many Persons One Project
  @JoinColumn(name = "UNIMX1PROJECT_ID")
  @ManyToOne(cascade = CascadeType.ALL)
  private BiDirMX1Project project;

  public BiDirMX1Person(long l, String string) {
    this.id = l;
    this.name = string;
  }

  public BiDirMX1Project getProject() {
    return project;
  }

  public void setProject(BiDirMX1Project project) {
    this.project = project;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public Long getId() {
    return id;
  }

  public void setId(Long id) {
    this.id = id;
  }

  @Override
  public int hashCode() {
    int hash = 0;
    hash += (id != null ? id.hashCode() : 0);
    return hash;
  }

  @Override
  public boolean equals(Object object) {
    // TODO: Warning - this method won't work in the case the id fields are not
    // set
    if (!(object instanceof BiDirMX1Person)) {
      return false;
    }
    BiDirMX1Person other = (BiDirMX1Person) object;
    if ((this.id == null && other.id != null)
        || (this.id != null && !this.id.equals(other.id))) {
      return false;
    }
    return true;
  }

  @Override
  public String toString() {
    return "bidirmanyxone.BiDirMX1Person[id=" + id + "]";
  }

}

==> jakarta-persistence-tck-3.1.6.zip: persistence-tck/src/com/sun/ts/tests/jpa/core/relationship/bidirmanyxone/BiDirMX1Person.java <==
/*
 * Copyright (c) 2009, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package com.sun.ts.tests.jpa.core.relationship.bidirmanyxone;

import java.io.Serializable;

import jakarta.persistence.CascadeType;
import jakarta.persistence.Entity;
import jakarta.persistence.Id;
import jakarta.persistence.JoinColumn;
import jakarta.persistence.ManyToOne;

/**
 *
 * @author Raja Perumal
 */
@Entity
public class BiDirMX1Person implements Serializable {

  public BiDirMX1Person() {
  }

  private static final long serialVersionUID = 1L;

  @Id
  private Long id;

  private String name;

  // Many Persons One Project
  @JoinColumn(name = "UNIMX1PROJECT_ID")
  @ManyToOne(cascade = CascadeType.ALL)
  private BiDirMX1Project project;

  public BiDirMX1Person(long l, String string) {
    this.id = l;
    this.name = string;
  }

  public BiDirMX1Project getProject() {
    return project;
  }

  public void setProject(BiDirMX1Project project) {
    this.project = project;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public Long getId() {
    return id;
  }

  public void setId(Long id) {
    this.id = id;
  }

  @Override
  public int hashCode() {
    int hash = 0;
    hash += (id != null ? id.hashCode() : 0);
    return hash;
  }

  @Override
  public boolean equals(Object object) {
    // TODO: Warning - this method won't work in the case the id fields are not
    // set
    if (!(object instanceof BiDirMX1Person)) {
      return false;
    }
    BiDirMX1Person other = (BiDirMX1Person) object;
    if ((this.id == null && other.id != null)
        || (this.id != null && !this.id.equals(other.id))) {
      return false;
    }
    return true;
  }

  @Override
  public String toString() {
    return "bidirmanyxone.BiDirMX1Person[id=" + id + "]";
  }

}
